@@ -44,7 +44,7 @@ class Almoststatic():
         self.media = "media"
         """str: subfolder used to store media files"""
 
-        self.static_url = "/"
+        self.static_url = ""
         """str: default url prefix for static pages"""
 
         self.cache = True
@@ -116,7 +116,7 @@ class Almoststatic():
         """bool: method write_static set this to True and this let to know to
                  templates when we are writing static pages."""
 
-        self.vars['url_prefix'] = "/"
+        self.vars['url_prefix'] = ""
         """str: prefix for url's by default it is the root of site, but during
                 writing static pages this change to site url."""
 
@@ -277,9 +277,9 @@ class Almoststatic():
         """
         if self.media_prefix is None:
             media_prefix = os.path.join(
-                self.vars['url_prefix'], self.content, self.media)
+                self._relative_url(), self.content, self.media)
         else:
-            media_prefix = self.media_prefix
+            media_prefix = self._relative_url() + self.media_prefix
         filename = os.path.join(media_prefix, media_obj)
         return filename
 
@@ -294,7 +294,13 @@ class Almoststatic():
         Returns:
             str: the url for internal link
         """
-        return f"{self.vars['url_prefix']}{page}{self.vars['url_suffix']}"
+        return f"{self._relative_url()}{page}{self.vars['url_suffix']}"
+
+    def _relative_url(self):
+        """"""
+        if self.vars['url_prefix']:
+            return self.vars['url_prefix']
+        return '../' * self.page['pagename'].count('/')
 
     def meta_pages(self, subfolder=''):
         """Read metadata of all pages declared in ./content/pages folder. The
